==> theme-customizer_0.9-46.tar.gz: theme-customizer-0.9/src/opt/theme-customizer/lang/Chinese.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>MainWindow</name>
    <message>
        <source>Selected theme is currently in use!</source>
        <translation>选定的主题是目前正在使用!</translation>
    </message>
    <message>
        <source>Current theme: </source>
        <translation>当前主题:</translation>
    </message>
    <message>
        <source>Export theme</source>
        <translation>导出主题</translation>
    </message>
    <message>
        <source>Import theme</source>
        <translation>导入主题</translation>
    </message>
    <message>
        <source>Exporting theme</source>
        <translation>导出主题</translation>
    </message>
    <message>
        <source>Select .tgz file to import</source>
        <translation>选择导入.tgz文件</translation>
    </message>
    <message>
        <source>Importing theme</source>
        <translation>导入主题</translation>
    </message>
    <message>
        <source>You can&apos;t delete a theme that&apos;s currently active.</source>
        <translation>无法删除当前活动的主题.</translation>
    </message>
    <message>
        <source>Delete saved themes</source>
        <translation>删除保存的主题</translation>
    </message>
    <message>
        <source>Delete theme?</source>
        <translation>删除主题?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this theme?</source>
        <translation>确定要删除这个主题吗?</translation>
    </message>
    <message>
        <source>Theme deleted.</source>
        <translation>主题删除.</translation>
    </message>
    <message>
        <source>+1</source>
        <translation>+1</translation>
    </message>
    <message>
        <source>+3</source>
        <translation>+3</translation>
    </message>
    <message>
        <source>+5</source>
        <translation>+5</translation>
    </message>
    <message>
        <source>-1</source>
        <translation>-1</translation>
    </message>
    <message>
        <source>-3</source>
        <translation>-3</translation>
    </message>
    <message>
        <source>-5</source>
        <translation>-5</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>文本</translation>
    </message>
    <message>
        <source>Preset saved!</source>
        <translation>保存配置!</translation>
    </message>
    <message>
        <source>Setting up icon theme...</source>
        <translation>设置图标主题...</translation>
    </message>
    <message>
        <source>Restoring files from backup</source>
        <translation>从备份文件中恢复</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Disabled font</source>
        <translation>禁用字体</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>图标主题</translation>
    </message>
    <message>
        <source>Import fonts from folder</source>
        <translation>从文件夹导入字体</translation>
    </message>
    <message>
        <source>Delete color preset?</source>
        <translation>删除色彩配置?</translation>
    </message>
    <message>
        <source>Menu bar opacity</source>
        <translation>菜单栏透明度</translation>
    </message>
    <message>
        <source>Show app shortcut backgrounds</source>
        <translation>显示程序快捷方式背景</translation>
    </message>
    <message>
        <source>Setting up widget opacities...</source>
        <translation>设置widget透明度...</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation>应用更改</translation>
    </message>
    <message>
        <source>Save color preset</source>
        <translation>保存色彩配置</translation>
    </message>
    <message>
        <source>Web bookmark size</source>
        <translation>网页书签尺寸</translation>
    </message>
    <message>
        <source>Secondary font</source>
        <translation>次要字体</translation>
    </message>
    <message>
        <source>&quot;Paint&quot; color</source>
        <translation>焦点颜色</translation>
    </message>
    <message>
        <source>Import all font files from MyDocs</source>
        <translation>从MyDocs导入所有字体</translation>
    </message>
    <message>
        <source>You must give name for the theme.</source>
        <translation>必须给主题命名.</translation>
    </message>
    <message>
        <source> already exists!</source>
        <translation>已存在!</translation>
    </message>
    <message>
        <source>Do you want to restore all original theme files?</source>
        <translation>要恢复原来的主题文件吗?</translation>
    </message>
    <message>
        <source>Setting up font family...</source>
        <translation>设置字体系列...</translation>
    </message>
    <message>
        <source>Auto-reboot after saving settings</source>
        <translation>保存设置后自动重启</translation>
    </message>
    <message>
        <source>Font size</source>
        <translation>字体尺寸</translation>
    </message>
    <message>
        <source>Setting up font colors...</source>
        <translation>设置字体颜色...</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Restoring files, please wait...</source>
        <translation>恢复文件,请等待...</translation>
    </message>
    <message>
        <source>App shortcut size</source>
        <translation>程序快捷方式尺寸</translation>
    </message>
    <message>
        <source>Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values.</source>
        <translation>重启服务,屏幕会闪烁!建议重启设备,才能重载所有新参数.</translation>
    </message>
    <message>
        <source>Button font</source>
        <translation>按键字体</translation>
    </message>
    <message>
        <source>About Theme Customizer</source>
        <translation>关于 Theme Customizer</translation>
    </message>
    <message>
        <source>Font colors</source>
        <translation>字体颜色</translation>
    </message>
    <message>
        <source>Reading settings</source>
        <translation>读取设置</translation>
    </message>
    <message>
        <source>DEFAULT</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Note: this function will only import .ttf and .otf fonts from root of MyDocs</source>
        <translation>注意:该功能只能从根目录的MyDocs里导入.ttf和.otf文件</translation>
    </message>
    <message>
        <source>Preset deleted.</source>
        <translation>配置删除.</translation>
    </message>
    <message>
        <source>Restore theme files</source>
        <translation>恢复主题文件</translation>
    </message>
    <message>
        <source>Color preset with this name already exists, do you want to overwrite it?</source>
        <translation>色彩配置的名称已存在,要替换吗?</translation>
    </message>
    <message>
        <source>Setting up shortcut and bookmark sizes...</source>
        <translation>设置快捷方式和书签尺寸...</translation>
    </message>
    <message>
        <source>Widget opacity</source>
        <translation>Widget透明度</translation>
    </message>
    <message>
        <source>Theme Customizer</source>
        <translation>Theme Customizer</translation>
    </message>
    <message>
        <source>Snap-to-grid size</source>
        <translation>对齐网格尺寸</translation>
    </message>
    <message>
        <source>Theme Customizer - font import</source>
        <translation>Theme Customizer - 导入字体</translation>
    </message>
    <message>
        <source>Ok, thanks.</source>
        <translation>好的,谢谢.</translation>
    </message>
    <message>
        <source>Button pressed</source>
        <translation>按下按键</translation>
    </message>
    <message>
        <source>Preset loaded.</source>
        <translation>配置载入.</translation>
    </message>
    <message>
        <source>Searching and importing fonts, please wait...</source>
        <translation>搜索并导入字体,请等待...</translation>
    </message>
    <message>
        <source>Save and reboot</source>
        <translation>保存并重启</translation>
    </message>
    <message>
        <source>Active font</source>
        <translation>有效字体</translation>
    </message>
    <message>
        <source>Restarting services...</source>
        <translation>重启服务...</translation>
    </message>
    <message>
        <source>Homescreen</source>
        <translation>主屏幕</translation>
    </message>
    <message>
        <source>Primary font</source>
        <translation>主要字体</translation>
    </message>
    <message>
        <source>Creating backups...</source>
        <translation>创建备份...</translation>
    </message>
    <message>
        <source>Theme Customizer - restore files</source>
        <translation>Theme Customizer - 恢复文件</translation>
    </message>
    <message>
        <source>Folder </source>
        <translation>文件夹</translation>
    </message>
    <message>
        <source>Change backgrounds</source>
        <translation>更改背景</translation>
    </message>
    <message>
        <source>Setting up snap-to-grid...</source>
        <translation>设置对齐网格...</translation>
    </message>
    <message>
        <source>Color presets</source>
        <translation>色彩配置</translation>
    </message>
    <message>
        <source>Importing fonts</source>
        <translation>导入字体</translation>
    </message>
    <message>
        <source>Painted font</source>
        <translation>触发字体</translation>
    </message>
    <message>
        <source>Setting up the theme, please wait...</source>
        <translation>设置主题,请等待...</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this preset?</source>
        <translation>确定要删除该配置吗?</translation>
    </message>
    <message>
        <source>Saving new theme...</source>
        <translation>保存新主题...</translation>
    </message>
    <message>
        <source>You must give name for the preset.</source>
        <translation>必须给配置命名.</translation>
    </message>
    <message>
        <source>Overwrite color preset?</source>
        <translation>替换色彩配置?</translation>
    </message>
    <message>
        <source>Setting up font sizes...</source>
        <translation>设置字体尺寸...</translation>
    </message>
    <message>
        <source>Reading settings...</source>
        <translation>读取设置...</translation>
    </message>
    <message>
        <source>Do you want to import fonts from MyDocs?</source>
        <translation>要从MyDocs导入字体吗?</translation>
    </message>
    <message>
        <source>Save as new theme</source>
        <translation>另存为新主题</translation>
    </message>
</context>
<context>
    <name>managepresets</name>
    <message>
        <source>Load</source>
        <translation>读取</translation>
    </message>
    <message>
        <source>Choose color preset:</source>
        <translation>选择色彩配置:</translation>
    </message>
    <message>
        <source>Original colors of current theme</source>
        <translation>当前主题原来的色彩</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Manage color presets</source>
        <translation>管理色彩配置</translation>
    </message>
    <message>
        <source>Currently active colors</source>
        <translation>当前有效色彩</translation>
    </message>
</context>
<context>
    <name>savenewtheme</name>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Save theme as...</source>
        <translation>主题另存为...</translation>
    </message>
</context>
<context>
    <name>savepreset</name>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Save color preset</source>
        <translation>保存色彩配置</translation>
    </message>
    <message>
        <source>Save color preset as...</source>
        <translation>色彩配置另存为...</translation>
    </message>
</context>
<context>
    <name>backgrounds</name>
    <message>
        <source>Clock</source>
        <translation>时钟</translation>
    </message>
    <message>
        <source>Media Player</source>
        <translation>媒体播放器</translation>
    </message>
    <message>
        <source>Processing image</source>
        <translation>处理图像</translation>
    </message>
    <message>
        <source>Tap me to change</source>
        <translation>变更点我</translation>
    </message>
    <message>
        <source>Image saved!</source>
        <translation>保存图像!</translation>
    </message>
    <message>
        <source>Lockscreen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <source>App Manager</source>
        <translation>程序管理器</translation>
    </message>
    <message>
        <source>Select image</source>
        <translation>选择图像</translation>
    </message>
    <message>
        <source>Set image</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>背景</translation>
    </message>
</context>
<context>
    <name>managethemes</name>
    <message>
        <source>Select theme:</source>
        <translation>选择主题:</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>No themes created by Theme Customizer found</source>
        <translation>没有找到被创建的主题</translation>
    </message>
</context>
</TS>

==> theme-customizer_0.9-51.tar.gz: theme-customizer-0.9/src/opt/theme-customizer/lang/Chinese.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>MainWindow</name>
    <message>
        <source>Selected theme is currently in use!</source>
        <translation>选定的主题是目前正在使用!</translation>
    </message>
    <message>
        <source>Current theme: </source>
        <translation>当前主题:</translation>
    </message>
    <message>
        <source>Use custom (fast) window transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Setting up window transitions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export theme</source>
        <translation>导出主题</translation>
    </message>
    <message>
        <source>Import theme</source>
        <translation>导入主题</translation>
    </message>
    <message>
        <source>Exporting theme</source>
        <translation>导出主题</translation>
    </message>
    <message>
        <source>Select .tgz file to import</source>
        <translation>选择导入.tgz文件</translation>
    </message>
    <message>
        <source>Importing theme</source>
        <translation>导入主题</translation>
    </message>
    <message>
        <source>You can&apos;t delete a theme that&apos;s currently active.</source>
        <translation>无法删除当前活动的主题.</translation>
    </message>
    <message>
        <source>Delete saved themes</source>
        <translation>删除保存的主题</translation>
    </message>
    <message>
        <source>Delete theme?</source>
        <translation>删除主题?</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this theme?</source>
        <translation>确定要删除这个主题吗?</translation>
    </message>
    <message>
        <source>Theme deleted.</source>
        <translation>主题删除.</translation>
    </message>
    <message>
        <source>+1</source>
        <translation>+1</translation>
    </message>
    <message>
        <source>+3</source>
        <translation>+3</translation>
    </message>
    <message>
        <source>+5</source>
        <translation>+5</translation>
    </message>
    <message>
        <source>-1</source>
        <translation>-1</translation>
    </message>
    <message>
        <source>-3</source>
        <translation>-3</translation>
    </message>
    <message>
        <source>-5</source>
        <translation>-5</translation>
    </message>
    <message>
        <source>No</source>
        <translation>否</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>是</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <source>Test</source>
        <translation>文本</translation>
    </message>
    <message>
        <source>Preset saved!</source>
        <translation>保存配置!</translation>
    </message>
    <message>
        <source>Setting up icon theme...</source>
        <translation>设置图标主题...</translation>
    </message>
    <message>
        <source>Restoring files from backup</source>
        <translation>从备份文件中恢复</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>忽略</translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Disabled font</source>
        <translation>禁用字体</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>图标主题</translation>
    </message>
    <message>
        <source>Import fonts from folder</source>
        <translation>从文件夹导入字体</translation>
    </message>
    <message>
        <source>Delete color preset?</source>
        <translation>删除色彩配置?</translation>
    </message>
    <message>
        <source>Menu bar opacity</source>
        <translation>菜单栏透明度</translation>
    </message>
    <message>
        <source>Show app shortcut backgrounds</source>
        <translation>显示程序快捷方式背景</translation>
    </message>
    <message>
        <source>Setting up widget opacities...</source>
        <translation>设置widget透明度...</translation>
    </message>
    <message>
        <source>Apply changes</source>
        <translation>应用更改</translation>
    </message>
    <message>
        <source>Save color preset</source>
        <translation>保存色彩配置</translation>
    </message>
    <message>
        <source>Web bookmark size</source>
        <translation>网页书签尺寸</translation>
    </message>
    <message>
        <source>Secondary font</source>
        <translation>次要字体</translation>
    </message>
    <message>
        <source>&quot;Paint&quot; color</source>
        <translation>焦点颜色</translation>
    </message>
    <message>
        <source>Import all font files from MyDocs</source>
        <translation>从MyDocs导入所有字体</translation>
    </message>
    <message>
        <source>You must give name for the theme.</source>
        <translation>必须给主题命名.</translation>
    </message>
    <message>
        <source> already exists!</source>
        <translation>已存在!</translation>
    </message>
    <message>
        <source>Do you want to restore all original theme files?</source>
        <translation>要恢复原来的主题文件吗?</translation>
    </message>
    <message>
        <source>Setting up font family...</source>
        <translation>设置字体系列...</translation>
    </message>
    <message>
        <source>Auto-reboot after saving settings</source>
        <translation>保存设置后自动重启</translation>
    </message>
    <message>
        <source>Font size</source>
        <translation>字体尺寸</translation>
    </message>
    <message>
        <source>Setting up font colors...</source>
        <translation>设置字体颜色...</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Restoring files, please wait...</source>
        <translation>恢复文件,请等待...</translation>
    </message>
    <message>
        <source>App shortcut size</source>
        <translation>程序快捷方式尺寸</translation>
    </message>
    <message>
        <source>Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values.</source>
        <translation>重启服务,屏幕会闪烁!建议重启设备,才能重载所有新参数.</translation>
    </message>
    <message>
        <source>Button font</source>
        <translation>按键字体</translation>
    </message>
    <message>
        <source>About Theme Customizer</source>
        <translation>关于 Theme Customizer</translation>
    </message>
    <message>
        <source>Font colors</source>
        <translation>字体颜色</translation>
    </message>
    <message>
        <source>Reading settings</source>
        <translation>读取设置</translation>
    </message>
    <message>
        <source>DEFAULT</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Note: this function will only import .ttf and .otf fonts from root of MyDocs</source>
        <translation>注意:该功能只能从根目录的MyDocs里导入.ttf和.otf文件</translation>
    </message>
    <message>
        <source>Preset deleted.</source>
        <translation>配置删除.</translation>
    </message>
    <message>
        <source>Restore theme files</source>
        <translation>恢复主题文件</translation>
    </message>
    <message>
        <source>Color preset with this name already exists, do you want to overwrite it?</source>
        <translation>色彩配置的名称已存在,要替换吗?</translation>
    </message>
    <message>
        <source>Setting up shortcut and bookmark sizes...</source>
        <translation>设置快捷方式和书签尺寸...</translation>
    </message>
    <message>
        <source>Widget opacity</source>
        <translation>Widget透明度</translation>
    </message>
    <message>
        <source>Theme Customizer</source>
        <translation>Theme Customizer</translation>
    </message>
    <message>
        <source>Snap-to-grid size</source>
        <translation>对齐网格尺寸</translation>
    </message>
    <message>
        <source>Theme Customizer - font import</source>
        <translation>Theme Customizer - 导入字体</translation>
    </message>
    <message>
        <source>Ok, thanks.</source>
        <translation>好的,谢谢.</translation>
    </message>
    <message>
        <source>Button pressed</source>
        <translation>按下按键</translation>
    </message>
    <message>
        <source>Preset loaded.</source>
        <translation>配置载入.</translation>
    </message>
    <message>
        <source>Searching and importing fonts, please wait...</source>
        <translation>搜索并导入字体,请等待...</translation>
    </message>
    <message>
        <source>Save and reboot</source>
        <translation>保存并重启</translation>
    </message>
    <message>
        <source>Active font</source>
        <translation>有效字体</translation>
    </message>
    <message>
        <source>Restarting services...</source>
        <translation>重启服务...</translation>
    </message>
    <message>
        <source>Homescreen</source>
        <translation>主屏幕</translation>
    </message>
    <message>
        <source>Primary font</source>
        <translation>主要字体</translation>
    </message>
    <message>
        <source>Creating backups...</source>
        <translation>创建备份...</translation>
    </message>
    <message>
        <source>Theme Customizer - restore files</source>
        <translation>Theme Customizer - 恢复文件</translation>
    </message>
    <message>
        <source>Folder </source>
        <translation>文件夹</translation>
    </message>
    <message>
        <source>Change backgrounds</source>
        <translation>更改背景</translation>
    </message>
    <message>
        <source>Setting up snap-to-grid...</source>
        <translation>设置对齐网格...</translation>
    </message>
    <message>
        <source>Color presets</source>
        <translation>色彩配置</translation>
    </message>
    <message>
        <source>Importing fonts</source>
        <translation>导入字体</translation>
    </message>
    <message>
        <source>Painted font</source>
        <translation>触发字体</translation>
    </message>
    <message>
        <source>Setting up the theme, please wait...</source>
        <translation>设置主题,请等待...</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this preset?</source>
        <translation>确定要删除该配置吗?</translation>
    </message>
    <message>
        <source>Saving new theme...</source>
        <translation>保存新主题...</translation>
    </message>
    <message>
        <source>You must give name for the preset.</source>
        <translation>必须给配置命名.</translation>
    </message>
    <message>
        <source>Overwrite color preset?</source>
        <translation>替换色彩配置?</translation>
    </message>
    <message>
        <source>Setting up font sizes...</source>
        <translation>设置字体尺寸...</translation>
    </message>
    <message>
        <source>Reading settings...</source>
        <translation>读取设置...</translation>
    </message>
    <message>
        <source>Do you want to import fonts from MyDocs?</source>
        <translation>要从MyDocs导入字体吗?</translation>
    </message>
    <message>
        <source>Save as new theme</source>
        <translation>另存为新主题</translation>
    </message>
</context>
<context>
    <name>managepresets</name>
    <message>
        <source>Load</source>
        <translation>读取</translation>
    </message>
    <message>
        <source>Choose color preset:</source>
        <translation>选择色彩配置:</translation>
    </message>
    <message>
        <source>Original colors of current theme</source>
        <translation>当前主题原来的色彩</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Manage color presets</source>
        <translation>管理色彩配置</translation>
    </message>
    <message>
        <source>Currently active colors</source>
        <translation>当前有效色彩</translation>
    </message>
</context>
<context>
    <name>savenewtheme</name>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Save theme as...</source>
        <translation>主题另存为...</translation>
    </message>
</context>
<context>
    <name>savepreset</name>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Save color preset</source>
        <translation>保存色彩配置</translation>
    </message>
    <message>
        <source>Save color preset as...</source>
        <translation>色彩配置另存为...</translation>
    </message>
</context>
<context>
    <name>backgrounds</name>
    <message>
        <source>Clock</source>
        <translation>时钟</translation>
    </message>
    <message>
        <source>Media Player</source>
        <translation>媒体播放器</translation>
    </message>
    <message>
        <source>Processing image</source>
        <translation>处理图像</translation>
    </message>
    <message>
        <source>Tap me to change</source>
        <translation>变更点我</translation>
    </message>
    <message>
        <source>Image saved!</source>
        <translation>保存图像!</translation>
    </message>
    <message>
        <source>Lockscreen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <source>App Manager</source>
        <translation>程序管理器</translation>
    </message>
    <message>
        <source>Select image</source>
        <translation>选择图像</translation>
    </message>
    <message>
        <source>Set image</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Backgrounds</source>
        <translation>背景</translation>
    </message>
</context>
<context>
    <name>managethemes</name>
    <message>
        <source>Select theme:</source>
        <translation>选择主题:</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>No themes created by Theme Customizer found</source>
        <translation>没有找到被创建的主题</translation>
    </message>
</context>
</TS>
